@@ -1,9 +1,13 @@
+from typing import Iterable
 import numpy as np
 from difflib import get_close_matches
 import re
 import mimetypes
 from werkzeug.datastructures import FileStorage
 import tempfile
+import pandas as pd
+import json
+from typing import Union, List, Tuple
 
 
 """
@@ -53,7 +57,6 @@ def pull_not_val(df, col_name, value):  # *
     """
     return df.where(df[col_name] != value).dropna()
 
-
 def id_nearest_col(df, name, similarity_ratio=0.5, case_insensitive=True):  # *
     """Sends closest column to input column name provided that it is at least 50% similar. CASE INSENSITIVE.
 
@@ -182,3 +185,87 @@ def store_df(df, ext):
         filename=f'test.{ext}',
         content_type=type,
     )
+    
+def df_2_json(df:pd.DataFrame) -> str:  # *
+    """Converts from dataframe to JSON string.
+
+    Args:
+        df (pd.DataFrame): Data.
+
+    Returns:
+        str: JSON string data.
+    """
+    return json.dumps(df.to_numpy().tolist())
+
+def z_norm(df:pd.DataFrame) -> pd.DataFrame:
+    """Normalized dataframe to a mean of 0 and standard deviation of 1.
+
+    Args:
+        df (pd.DataFrame): Data to transform.
+
+    Returns:
+        pd.DataFrame: Normalized data.
+    """
+    return (df - df.mean())/df.std()
+
+def compare(inner_df:pd.DataFrame, outer_df:pd.DataFrame, inner_column:str, outer_column:str,
+            find_same:bool=True) -> pd.DataFrame:
+    """Compares two DataFrames along two specified column names.
+
+    Args:
+        inner_df (pd.DataFrame): Data to search for in outer_df.
+        outer_df (pd.DataFrame): Data to query with inner_df.
+        inner_column (str): Name of column to compare along in inner_df.
+        outer_column (str): Name of column to compare along in outer_df.
+        find_same (bool, optional): If True returns same values, if False returns values in outer_df column not found in
+            inner_df column. Defaults to True.
+
+    Returns:
+        pd.DataFrame: outer_df with condition specified by find_same.
+    """
+    outer_in_inner = outer_df[outer_column].isin(inner_df[inner_column])
+    indices = outer_in_inner[(outer_in_inner if find_same else ~outer_in_inner)].index
+    return outer_df.iloc[indices]
+
+def concat(dfs:Iterable[pd.DataFrame], drop_uncommon_columns:bool=True) -> pd.DataFrame:
+    """Wrapper for pd.concat. Stacks DataFrames and sorts.
+
+    Args:
+        dfs (Iterable[pd.DataFrame]): Collection of DataFrames.
+        drop_uncommon_columns (bool, optional): Determines pd join method. Defaults to True.
+
+    Returns:
+        pd.DataFrame: Concatenated data.
+    """
+    return pd.concat(dfs, axis=0, ignore_index=True, join=('inner' if drop_uncommon_columns else 'outer'), sort=True)
+
+def sync_na_drop(df:Union[pd.DataFrame, pd.Series], col_s:Union[str, List[str]], *iterables:Iterable,
+                 all_na:bool=True) -> Tuple[pd.DataFrame, Union[list, List[list]]]:
+    """Syncs NaN values in a dataframe with a list of iterables.
+
+    Args:
+        df (pd.DataFrame): Data to drop from.
+        col_s (Union[str, list]): Name of single column or list of columns to subset for drop.
+        all_na (bool): True, drops row only if all values in row are NaN. Else drops row if any values is NaN.
+        Defaults to True.
+
+    Returns:
+        Tuple[List[Iterable], pd.DataFrame]: Tuple of list of masked iterables and NA dropped DataFrame.
+    """
+    if not all(len(i) == len(df) for i in iterables):
+        raise ValueError('All iterables must be the same length as the dataframe.')
+     
+    f = df[col_s].isnull
+    if isinstance(df[col_s], pd.DataFrame):
+        is_na_mask = f().all(axis=1) if all_na else f().any(axis=1)
+    elif isinstance(df[col_s], pd.Series):
+        is_na_mask = f()
+    
+    if len(iterables) == 1:
+        out = np.array(iterables[0])[~is_na_mask].tolist()
+    else:
+        out = [np.array(it)[~is_na_mask].tolist() for it in iterables]
+
+    subset = list(col_s) if not isinstance(col_s, str) else [col_s]
+    return (df.dropna(subset=subset, how=('all' if all_na else 'any')),
+            out)
