@@ -13,11 +13,11 @@ class TestWeb(unittest.TestCase):
         })
         return super().setUpClass()
     
-    def test_read_shreadsheet(self):
+    def test_filemime_2_df(self):
         # Test csv
         mock_file = dataframes.store_df(self.df, 'csv')
         pd.testing.assert_frame_equal(
-            web.read_spreadsheet(mock_file), 
+            web.filemime_2_df(mock_file), 
             self.df
         )
         mock_file.close()
@@ -25,7 +25,7 @@ class TestWeb(unittest.TestCase):
         # Test excel
         mock_file = dataframes.store_df(self.df, 'xlsx')
         pd.testing.assert_frame_equal(
-            web.read_spreadsheet(mock_file), 
+            web.filemime_2_df(mock_file), 
             self.df
         )
         mock_file.close()
@@ -33,7 +33,32 @@ class TestWeb(unittest.TestCase):
         # Test csv
         mock_file = dataframes.store_df(self.df, 'tsv')
         pd.testing.assert_frame_equal(
-            web.read_spreadsheet(mock_file), 
+            web.filemime_2_df(mock_file), 
+            self.df
+        )
+        mock_file.close()
+        
+    def test_filename_2_df(self):
+        # Test csv
+        mock_file = dataframes.store_df(self.df, 'csv')
+        pd.testing.assert_frame_equal(
+            web.filemime_2_df(mock_file), 
+            self.df
+        )
+        mock_file.close()
+        
+        # Test excel
+        mock_file = dataframes.store_df(self.df, 'xlsx')
+        pd.testing.assert_frame_equal(
+            web.filemime_2_df(mock_file), 
+            self.df
+        )
+        mock_file.close()
+        
+        # Test csv
+        mock_file = dataframes.store_df(self.df, 'tsv')
+        pd.testing.assert_frame_equal(
+            web.filemime_2_df(mock_file), 
             self.df
         )
         mock_file.close()
